@@ -1,4 +1,4 @@
-/*! imagesLoaded "PACKAGED" v3.0.4 */
+/*! imagesLoaded "PACKAGED" v3.1.8 */
 /*!
  * EventEmitter v4.2.6 - git.io/ee
  * Oliver Caldwell
@@ -472,7 +472,7 @@
 	}
 }.call(this));
 /*!
- * eventie v1.0.3
+ * eventie v1.0.4
  * event binding helper
  *   eventie.bind( elem, 'click', myFn )
  *   eventie.unbind( elem, 'click', myFn )
@@ -489,6 +489,13 @@ var docElem = document.documentElement;
 
 var bind = function() {};
 
+function getIEEvent( obj ) {
+  var event = window.event;
+  // add event.target
+  event.target = event.target || event.srcElement || obj;
+  return event;
+}
+
 if ( docElem.addEventListener ) {
   bind = function( obj, type, fn ) {
     obj.addEventListener( type, fn, false );
@@ -497,15 +504,11 @@ if ( docElem.addEventListener ) {
   bind = function( obj, type, fn ) {
     obj[ type + fn ] = fn.handleEvent ?
       function() {
-        var event = window.event;
-        // add event.target
-        event.target = event.target || event.srcElement;
+        var event = getIEEvent( obj );
         fn.handleEvent.call( fn, event );
       } :
       function() {
-        var event = window.event;
-        // add event.target
-        event.target = event.target || event.srcElement;
+        var event = getIEEvent( obj );
         fn.call( obj, event );
       };
     obj.attachEvent( "on" + type, obj[ type + fn ] );
@@ -546,11 +549,45 @@ if ( typeof define === 'function' && define.amd ) {
 
 })( this );
 /*!
- * imagesLoaded v3.0.4
+ * imagesLoaded v3.1.8
  * JavaScript is all like "You images are done yet or what?"
+ * MIT License
  */
 
-( function( window ) {
+( function( window, factory ) { 'use strict';
+  // universal module definition
+
+  /*global define: false, module: false, require: false */
+
+  if ( typeof define === 'function' && define.amd ) {
+    // AMD
+    define( [
+      'eventEmitter/EventEmitter',
+      'eventie/eventie'
+    ], function( EventEmitter, eventie ) {
+      return factory( window, EventEmitter, eventie );
+    });
+  } else if ( typeof exports === 'object' ) {
+    // CommonJS
+    module.exports = factory(
+      window,
+      require('wolfy87-eventemitter'),
+      require('eventie')
+    );
+  } else {
+    // browser global
+    window.imagesLoaded = factory(
+      window,
+      window.EventEmitter,
+      window.eventie
+    );
+  }
+
+})( window,
+
+// --------------------------  factory -------------------------- //
+
+function factory( window, EventEmitter, eventie ) {
 
 'use strict';
 
@@ -591,9 +628,7 @@ function makeArray( obj ) {
   return ary;
 }
 
-// --------------------------  -------------------------- //
-
-function defineImagesLoaded( EventEmitter, eventie ) {
+  // -------------------------- imagesLoaded -------------------------- //
 
   /**
    * @param {Array, Element, NodeList, String} elem
@@ -652,6 +687,11 @@ function defineImagesLoaded( EventEmitter, eventie ) {
         this.addImage( elem );
       }
       // find children
+      // no non-element nodes, #143
+      var nodeType = elem.nodeType;
+      if ( !nodeType || !( nodeType === 1 || nodeType === 9 || nodeType === 11 ) ) {
+        continue;
+      }
       var childElems = elem.querySelectorAll('img');
       // concat childElems to filterFound array
       for ( var j=0, jLen = childElems.length; j < jLen; j++ ) {
@@ -706,7 +746,7 @@ function defineImagesLoaded( EventEmitter, eventie ) {
     var _this = this;
     setTimeout( function() {
       _this.emit( 'progress', _this, image );
-      if ( _this.jqDeferred ) {
+      if ( _this.jqDeferred && _this.jqDeferred.notify ) {
         _this.jqDeferred.notify( _this, image );
       }
     });
@@ -739,8 +779,6 @@ function defineImagesLoaded( EventEmitter, eventie ) {
 
   // --------------------------  -------------------------- //
 
-  var cache = {};
-
   function LoadingImage( img ) {
     this.img = img;
   }
@@ -749,13 +787,11 @@ function defineImagesLoaded( EventEmitter, eventie ) {
 
   LoadingImage.prototype.check = function() {
     // first check cached any previous images that have same src
-    var cached = cache[ this.img.src ];
-    if ( cached ) {
-      this.useCached( cached );
+    var resource = cache[ this.img.src ] || new Resource( this.img.src );
+    if ( resource.isConfirmed ) {
+      this.confirm( resource.isLoaded, 'cached was confirmed' );
       return;
     }
-    // add this to cache
-    cache[ this.img.src ] = this;
 
     // If complete is true and browser supports natural sizes,
     // try to check for image status manually.
@@ -766,73 +802,84 @@ function defineImagesLoaded( EventEmitter, eventie ) {
     }
 
     // If none of the checks above matched, simulate loading on detached element.
-    var proxyImage = this.proxyImage = new Image();
-    eventie.bind( proxyImage, 'load', this );
-    eventie.bind( proxyImage, 'error', this );
-    proxyImage.src = this.img.src;
-  };
+    var _this = this;
+    resource.on( 'confirm', function( resrc, message ) {
+      _this.confirm( resrc.isLoaded, message );
+      return true;
+    });
 
-  LoadingImage.prototype.useCached = function( cached ) {
-    if ( cached.isConfirmed ) {
-      this.confirm( cached.isLoaded, 'cached was confirmed' );
-    } else {
-      var _this = this;
-      cached.on( 'confirm', function( image ) {
-        _this.confirm( image.isLoaded, 'cache emitted confirmed' );
-        return true; // bind once
-      });
-    }
+    resource.check();
   };
 
   LoadingImage.prototype.confirm = function( isLoaded, message ) {
-    this.isConfirmed = true;
     this.isLoaded = isLoaded;
     this.emit( 'confirm', this, message );
   };
 
+  // -------------------------- Resource -------------------------- //
+
+  // Resource checks each src, only once
+  // separate class from LoadingImage to prevent memory leaks. See #115
+
+  var cache = {};
+
+  function Resource( src ) {
+    this.src = src;
+    // add to cache
+    cache[ src ] = this;
+  }
+
+  Resource.prototype = new EventEmitter();
+
+  Resource.prototype.check = function() {
+    // only trigger checking once
+    if ( this.isChecked ) {
+      return;
+    }
+    // simulate loading on detached element
+    var proxyImage = new Image();
+    eventie.bind( proxyImage, 'load', this );
+    eventie.bind( proxyImage, 'error', this );
+    proxyImage.src = this.src;
+    // set flag
+    this.isChecked = true;
+  };
+
+  // ----- events ----- //
+
   // trigger specified handler for event type
-  LoadingImage.prototype.handleEvent = function( event ) {
+  Resource.prototype.handleEvent = function( event ) {
     var method = 'on' + event.type;
     if ( this[ method ] ) {
       this[ method ]( event );
     }
   };
 
-  LoadingImage.prototype.onload = function() {
+  Resource.prototype.onload = function( event ) {
     this.confirm( true, 'onload' );
-    this.unbindProxyEvents();
+    this.unbindProxyEvents( event );
   };
 
-  LoadingImage.prototype.onerror = function() {
+  Resource.prototype.onerror = function( event ) {
     this.confirm( false, 'onerror' );
-    this.unbindProxyEvents();
+    this.unbindProxyEvents( event );
   };
 
-  LoadingImage.prototype.unbindProxyEvents = function() {
-    eventie.unbind( this.proxyImage, 'load', this );
-    eventie.unbind( this.proxyImage, 'error', this );
+  // ----- confirm ----- //
+
+  Resource.prototype.confirm = function( isLoaded, message ) {
+    this.isConfirmed = true;
+    this.isLoaded = isLoaded;
+    this.emit( 'confirm', this, message );
+  };
+
+  Resource.prototype.unbindProxyEvents = function( event ) {
+    eventie.unbind( event.target, 'load', this );
+    eventie.unbind( event.target, 'error', this );
   };
 
   // -----  ----- //
 
   return ImagesLoaded;
-}
 
-// -------------------------- transport -------------------------- //
-
-if ( typeof define === 'function' && define.amd ) {
-  // AMD
-  define( [
-      'eventEmitter/EventEmitter',
-      'eventie/eventie'
-    ],
-    defineImagesLoaded );
-} else {
-  // browser global
-  window.imagesLoaded = defineImagesLoaded(
-    window.EventEmitter,
-    window.eventie
-  );
-}
-
-})( window );
+});
